@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -55,7 +55,7 @@ class QByteArray;
 class QString;
 
 #ifndef Q_MOC_OUTPUT_REVISION
-#define Q_MOC_OUTPUT_REVISION 61
+#define Q_MOC_OUTPUT_REVISION 62
 #endif
 
 // The following macros are our "extensions" to C++
@@ -78,6 +78,7 @@ class QString;
 #define Q_CLASSINFO(name, value)
 #define Q_INTERFACES(x)
 #define Q_PROPERTY(text)
+#define Q_PRIVATE_PROPERTY(d, text)
 #define Q_OVERRIDE(text)
 #define Q_ENUMS(x)
 #define Q_FLAGS(x)
@@ -145,11 +146,18 @@ template <typename T1, typename T2>
 inline void qYouForgotTheQ_OBJECT_Macro(T1, T2) {}
 #endif // QT_NO_MEMBER_TEMPLATES
 
+#ifdef Q_NO_DATA_RELOCATION
+#define Q_OBJECT_GETSTATICMETAOBJECT static const QMetaObject &getStaticMetaObject();
+#else
+#define Q_OBJECT_GETSTATICMETAOBJECT
+#endif
+
 /* tmake ignore Q_OBJECT */
 #define Q_OBJECT \
 public: \
     Q_OBJECT_CHECK \
     static const QMetaObject staticMetaObject; \
+    Q_OBJECT_GETSTATICMETAOBJECT \
     virtual const QMetaObject *metaObject() const; \
     virtual void *qt_metacast(const char *); \
     QT_TR_FUNCTIONS \
@@ -161,6 +169,7 @@ private:
 #define Q_GADGET \
 public: \
     static const QMetaObject staticMetaObject; \
+    Q_OBJECT_GETSTATICMETAOBJECT \
 private:
 #else // Q_MOC_RUN
 #define slots slots
@@ -170,6 +179,7 @@ private:
 #define Q_CLASSINFO(name, value) Q_CLASSINFO(name, value)
 #define Q_INTERFACES(x) Q_INTERFACES(x)
 #define Q_PROPERTY(text) Q_PROPERTY(text)
+#define Q_PRIVATE_PROPERTY(d, text) Q_PRIVATE_PROPERTY(d, text)
 #define Q_OVERRIDE(text) Q_OVERRIDE(text)
 #define Q_ENUMS(x) Q_ENUMS(x)
 #define Q_FLAGS(x) Q_FLAGS(x)
@@ -263,6 +273,14 @@ public:
         : QGenericArgument(aName, static_cast<const void *>(&aData))
         {}
 };
+template <class T>
+class QArgument<T &>: public QGenericArgument
+{
+public:
+    inline QArgument(const char *aName, T &aData)
+        : QGenericArgument(aName, static_cast<const void *>(&aData))
+        {}
+};
 
 
 template <typename T>
@@ -326,14 +344,17 @@ struct Q_CORE_EXPORT QMetaObject
     // internal index-based disconnect
     static bool disconnect(const QObject *sender, int signal_index,
                            const QObject *receiver, int method_index);
+    static bool disconnectOne(const QObject *sender, int signal_index,
+                              const QObject *receiver, int method_index);
     // internal slot-name based connect
     static void connectSlotsByName(QObject *o);
 
     // internal index-based signal activation
-    static void activate(QObject *sender, int signal_index, void **argv);
-    static void activate(QObject *sender, int from_signal_index, int to_signal_index, void **argv);
+    static void activate(QObject *sender, int signal_index, void **argv);  //obsolete
+    static void activate(QObject *sender, int from_signal_index, int to_signal_index, void **argv); //obsolete
     static void activate(QObject *sender, const QMetaObject *, int local_signal_index, void **argv);
-    static void activate(QObject *sender, const QMetaObject *, int from_local_signal_index, int to_local_signal_index, void **argv);
+    static void activate(QObject *sender, const QMetaObject *, int from_local_signal_index, int to_local_signal_index, void **argv); //obsolete
+
     // internal guarded pointers
     static void addGuard(QObject **ptr);
     static void removeGuard(QObject **ptr);
@@ -428,6 +449,7 @@ struct Q_CORE_EXPORT QMetaObject
     };
 
     int static_metacall(Call, int, void **) const;
+    static int metacall(QObject *, Call, int, void **);
 
 #ifdef QT3_SUPPORT
     QT3_SUPPORT const char *superClassName() const;
@@ -439,11 +461,18 @@ struct Q_CORE_EXPORT QMetaObject
         const uint *data;
         const void *extradata;
     } d;
+
 };
 
+typedef const QMetaObject& (*QMetaObjectAccessor)();
+
 struct QMetaObjectExtraData
 {
+#ifdef Q_NO_DATA_RELOCATION
+    const QMetaObjectAccessor *objects;
+#else
     const QMetaObject **objects;
+#endif
     int (*static_metacall)(QMetaObject::Call, int, void **);
 };
 
