@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -78,17 +78,22 @@ private:
     QString q_pattern;
     Qt::CaseSensitivity q_cs;
 #ifdef Q_CC_RVCT
-// explicitely allow anonymous unions for RVCT to prevent compiler warnings
-#pragma anon_unions
+// explicitly allow anonymous unions for RVCT to prevent compiler warnings
+#  pragma push
+#  pragma anon_unions
 #endif
+    struct Data {
+        uchar q_skiptable[256];
+        const QChar *uc;
+        int len;
+    };
     union {
         uint q_data[256];
-        struct {
-            uchar q_skiptable[256];
-            const QChar *uc;
-            int len;
-        } p;
+        Data p;
     };
+#ifdef Q_CC_RVCT
+#  pragma pop
+#endif
 };
 
 QT_END_NAMESPACE
