@@ -1,29 +1,48 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2005 Trolltech AS. All rights reserved.
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License version 2.0 as published by the Free Software Foundation
-** and appearing in the file LICENSE.GPL included in the packaging of
-** this file.  Please review the following information to ensure GNU
-** General Public Licensing requirements will be met:
-** http://www.trolltech.com/products/qt/opensource.html
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** If you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://www.trolltech.com/products/qt/licensing.html or contact the
-** sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
+**
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
+**
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #ifndef QDATASTREAM_H
 #define QDATASTREAM_H
 
+#include <QtCore/qscopedpointer.h>
 #include <QtCore/qiodevice.h>
 #include <QtCore/qglobal.h>
 
@@ -31,6 +50,10 @@
 #error qdatastream.h must be included before any header file that defines Status
 #endif
 
+QT_BEGIN_HEADER
+
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
 class QByteArray;
@@ -43,9 +66,8 @@ template <typename T> class QSet;
 template <class Key, class T> class QHash;
 template <class Key, class T> class QMap;
 
+#if !defined(QT_NO_DATASTREAM) || defined(QT_BOOTSTRAPPED)
 class QDataStreamPrivate;
-
-#ifndef QT_NO_DATASTREAM
 class Q_CORE_EXPORT QDataStream
 {
 public:
@@ -57,9 +79,16 @@ public:
         Qt_3_1 = 5,
         Qt_3_3 = 6,
         Qt_4_0 = 7,
-        Qt_4_1 = Qt_4_0
-#if QT_VERSION >= 0x040200
-#error Add Qt_4_2 = Qt_4_1
+        Qt_4_1 = Qt_4_0,
+        Qt_4_2 = 8,
+        Qt_4_3 = 9,
+        Qt_4_4 = 10,
+        Qt_4_5 = 11,
+        Qt_4_6 = 12,
+        Qt_4_7 = Qt_4_6
+#if QT_VERSION >= 0x040800
+#error Add the datastream version for this Qt version
+        Qt_4_8 = Qt_4_7
 #endif
     };
 
@@ -74,6 +103,11 @@ public:
 	ReadCorruptData
     };
 
+    enum FloatingPointPrecision {
+        SinglePrecision,
+        DoublePrecision
+    };
+
     QDataStream();
     explicit QDataStream(QIODevice *);
 #ifdef QT3_SUPPORT
@@ -96,6 +130,9 @@ public:
     void setStatus(Status status);
     void resetStatus();
 
+    FloatingPointPrecision floatingPointPrecision() const;
+    void setFloatingPointPrecision(FloatingPointPrecision precision);
+
     ByteOrder byteOrder() const;
     void setByteOrder(ByteOrder);
 
@@ -139,9 +176,9 @@ public:
 
 #ifdef QT3_SUPPORT
     inline QT3_SUPPORT QDataStream &readRawBytes(char *str, uint len)
-        { readRawData(str, (int)len); return *this; }
+        { readRawData(str, static_cast<int>(len)); return *this; }
     inline QT3_SUPPORT QDataStream &writeRawBytes(const char *str, uint len)
-        { writeRawData(str, (int)len); return *this; }
+        { writeRawData(str, static_cast<int>(len)); return *this; }
     inline QT3_SUPPORT bool isPrintableData() const { return false; }
     inline QT3_SUPPORT void setPrintableData(bool) {}
 #endif
@@ -149,7 +186,7 @@ public:
 private:
     Q_DISABLE_COPY(QDataStream)
 
-    QDataStreamPrivate *d;
+    QScopedPointer<QDataStreamPrivate> d;
 
     QIODevice *dev;
     bool owndev;
@@ -206,6 +243,7 @@ QDataStream& operator>>(QDataStream& s, QList<T>& l)
     l.clear();
     quint32 c;
     s >> c;
+    l.reserve(c);
     for(quint32 i = 0; i < c; ++i)
     {
         T t;
@@ -272,8 +310,7 @@ template<typename T>
 QDataStream& operator<<(QDataStream& s, const QVector<T>& v)
 {
     s << quint32(v.size());
-    const T* it = v.begin();
-    for(; it != v.end(); ++it)
+    for (typename QVector<T>::const_iterator it = v.begin(); it != v.end(); ++it)
         s << *it;
     return s;
 }
@@ -361,9 +398,7 @@ Q_OUTOFLINE_TEMPLATE QDataStream &operator>>(QDataStream &in, QMap<aKey, aT> &ma
     in >> n;
 
     map.detach();
-#if !defined(Q_CC_BOR)
-    map.d->insertInOrder = true;
-#endif
+    map.setInsertInOrder(true);
     for (quint32 i = 0; i < n; ++i) {
         if (in.status() != QDataStream::Ok)
             break;
@@ -373,9 +408,7 @@ Q_OUTOFLINE_TEMPLATE QDataStream &operator>>(QDataStream &in, QMap<aKey, aT> &ma
         in >> key >> value;
         map.insertMulti(key, value);
     }
-#if !defined(Q_CC_BOR)
-    map.d->insertInOrder = false;
-#endif
+    map.setInsertInOrder(false);
     if (in.status() != QDataStream::Ok)
         map.clear();
     if (oldStatus != QDataStream::Ok)
@@ -398,4 +431,8 @@ Q_OUTOFLINE_TEMPLATE QDataStream &operator<<(QDataStream &out, const QMap<Key, T
 
 #endif // QT_NO_DATASTREAM
 
+QT_END_NAMESPACE
+
+QT_END_HEADER
+
 #endif // QDATASTREAM_H
