@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -141,11 +141,10 @@ public:
     OSMenuRef macMenu(OSMenuRef merge=0);
 #endif
 
-#ifdef Q_OS_WINCE
-    HMENU wceMenu(bool create = false);
+#ifdef Q_WS_WINCE
+    HMENU wceMenu();
 #endif
 
-
     bool separatorsCollapsible() const;
     void setSeparatorsCollapsible(bool collapse);
 
@@ -163,7 +162,9 @@ protected:
     void mouseReleaseEvent(QMouseEvent *);
     void mousePressEvent(QMouseEvent *);
     void mouseMoveEvent(QMouseEvent *);
+#ifndef QT_NO_WHEELEVENT
     void wheelEvent(QWheelEvent *);
+#endif
     void enterEvent(QEvent *);
     void leaveEvent(QEvent *);
     void hideEvent(QHideEvent *);
@@ -174,7 +175,7 @@ protected:
     bool focusNextPrevChild(bool next);
     void initStyleOption(QStyleOptionMenuItem *option, const QAction *action) const;
 
-#ifdef Q_OS_WINCE
+#ifdef Q_WS_WINCE
     QAction* wceCommands(uint command);
 #endif
 
@@ -416,6 +417,7 @@ private:
     friend OSStatus qt_mac_menu_event(EventHandlerCallRef, EventRef, void *);
     friend bool qt_mac_activate_action(OSMenuRef, uint, QAction::ActionEvent, bool);
     friend void qt_mac_emit_menuSignals(QMenu *, bool);
+    friend void qt_mac_menu_emit_hovered(QMenu *menu, QAction *action);
 #endif
 };
 
