@@ -1,43 +1,41 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtGui module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** Commercial Usage
+** Licensees holding valid Qt Commercial licenses may use this file in
+** accordance with the Qt Commercial License Agreement provided with the
+** Software or, alternatively, in accordance with the terms contained in
+** a written agreement between you and Nokia.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** GNU Lesser General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU Lesser
+** General Public License version 2.1 as published by the Free Software
+** Foundation and appearing in the file LICENSE.LGPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU Lesser General Public License version 2.1 requirements
+** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights.  These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU
+** General Public License version 3.0 as published by the Free Software
+** Foundation and appearing in the file LICENSE.GPL included in the
+** packaging of this file.  Please review the following information to
+** ensure the GNU General Public License version 3.0 requirements will be
+** met: http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+** If you have questions regarding the use of this file, please contact
+** Nokia at qt-info@nokia.com.
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
@@ -51,6 +49,8 @@
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Gui)
 
 class QTextFormatCollection;
@@ -118,8 +118,12 @@ class Q_GUI_EXPORT QTextDocument : public QObject
     Q_PROPERTY(QSizeF size READ size)
     Q_PROPERTY(qreal textWidth READ textWidth WRITE setTextWidth)
     Q_PROPERTY(int blockCount READ blockCount)
+    Q_PROPERTY(qreal indentWidth READ indentWidth WRITE setIndentWidth)
+#ifndef QT_NO_CSSPARSER
     Q_PROPERTY(QString defaultStyleSheet READ defaultStyleSheet WRITE setDefaultStyleSheet)
+#endif
     Q_PROPERTY(int maximumBlockCount READ maximumBlockCount WRITE setMaximumBlockCount)
+    Q_PROPERTY(qreal documentMargin READ documentMargin WRITE setDocumentMargin)
     QDOC_PROPERTY(QTextOption defaultTextOption READ defaultTextOption WRITE setDefaultTextOption)
 
 public:
@@ -138,21 +142,31 @@ public:
     bool isUndoAvailable() const;
     bool isRedoAvailable() const;
 
+    int availableUndoSteps() const;
+    int availableRedoSteps() const;
+
+    int revision() const;
+
     void setDocumentLayout(QAbstractTextDocumentLayout *layout);
     QAbstractTextDocumentLayout *documentLayout() const;
 
     enum MetaInformation {
-        DocumentTitle
+        DocumentTitle,
+        DocumentUrl
     };
     void setMetaInformation(MetaInformation info, const QString &);
     QString metaInformation(MetaInformation info) const;
 
+#ifndef QT_NO_TEXTHTMLPARSER
     QString toHtml(const QByteArray &encoding = QByteArray()) const;
     void setHtml(const QString &html);
+#endif
 
     QString toPlainText() const;
     void setPlainText(const QString &text);
 
+    QChar characterAt(int pos) const;
+
     enum FindFlag
     {
         FindBackward        = 0x00001,
@@ -174,9 +188,14 @@ public:
     QTextObject *objectForFormat(const QTextFormat &) const;
 
     QTextBlock findBlock(int pos) const;
+    QTextBlock findBlockByNumber(int blockNumber) const;
+    QTextBlock findBlockByLineNumber(int blockNumber) const;
     QTextBlock begin() const;
     QTextBlock end() const;
 
+    QTextBlock firstBlock() const;
+    QTextBlock lastBlock() const;
+
     void setPageSize(const QSizeF &size);
     QSizeF pageSize() const;
 
@@ -216,17 +235,34 @@ public:
 
     qreal idealWidth() const;
 
+    qreal indentWidth() const;
+    void setIndentWidth(qreal width);
+
+    qreal documentMargin() const;
+    void setDocumentMargin(qreal margin);
+
     void adjustSize();
     QSizeF size() const;
 
     int blockCount() const;
+    int lineCount() const;
+    int characterCount() const;
 
+#ifndef QT_NO_CSSPARSER
     void setDefaultStyleSheet(const QString &sheet);
     QString defaultStyleSheet() const;
+#endif
 
     void undo(QTextCursor *cursor);
     void redo(QTextCursor *cursor);
 
+    enum Stacks {
+        UndoStack = 0x01,
+        RedoStack = 0x02,
+        UndoAndRedoStacks = UndoStack | RedoStack
+    };
+    void clearUndoRedoStacks(Stacks historyToClear = UndoAndRedoStacks);
+
     int maximumBlockCount() const;
     void setMaximumBlockCount(int maximum);
 
@@ -238,10 +274,13 @@ Q_SIGNALS:
     void contentsChanged();
     void undoAvailable(bool);
     void redoAvailable(bool);
+    void undoCommandAdded();
     void modificationChanged(bool m);
     void cursorPositionChanged(const QTextCursor &cursor);
     void blockCountChanged(int newBlockCount);
 
+    void documentLayoutChanged();
+
 public Q_SLOTS:
     void undo();
     void redo();
@@ -258,10 +297,13 @@ public:
 private:
     Q_DISABLE_COPY(QTextDocument)
     Q_DECLARE_PRIVATE(QTextDocument)
+    friend class QTextObjectPrivate;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(QTextDocument::FindFlags)
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QTEXTDOCUMENT_H
